# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------

from azdata.cli.core.deploy import get_environment_list_by_target

"""Help documentation for `bdc` commands."""

from knack.help_files import helps
from azdata.cli.commands.bdc import _

helps['bdc'] = """
    type: group
    short-summary: {short}
""".format(short=_('Select, manage, and operate SQL Server Big Data Clusters.'))

helps['bdc create'] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            azdata bdc create
        - name: {ex2}
          text: >
            azdata bdc create --accept-eula yes --config-profile ./path/to/config/profile
        - name: {ex3}
          text: >
            azdata bdc create --name <cluster_name> --accept-eula yes --config-profile aks-dev-test
        - name: {ex4}
          text: >
            azdata bdc create --accept-eula yes --config-profile aks-dev-test --force
""".format(
    short=_('Create Big Data Cluster.'),
    long=_('Create a SQL Server Big Data Cluster - Kubernetes configuration is required on your system along with the '
           'following environment variables {0}.'.format(get_environment_list_by_target('cluster'))),
    ex1=_('Guided BDC deployment experience - you will receive prompts for needed values.'),
    ex2=_('BDC deployment with arguments and custom config profile that was initialized via `azdata bdc config init`.'),
    ex3=_('BDC deployment with custom cluster name specified and a default config profile aks-dev-test.'),
    ex4=_('BDC deployment with arguments - no prompts will be given as the --force flag is used.'))

helps['bdc delete'] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            azdata bdc delete --name <cluster_name>
""".format(
    short=_('Delete Big Data Cluster.'),
    long=_('Delete the SQL Server Big Data Cluster - Kubernetes configuration is required on your system.'),
    ex1=_('BDC delete.'))

helps['bdc upgrade'] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            azdata bdc upgrade -t cu2
        - name: {ex2}
          text: >
            azdata bdc upgrade -t cu2 -r foo/bar/baz
        - name: {ex3}
          text: >
            azdata bdc upgrade -t cu2 --controller-timeout=30 --component-timeout=40 --stability-threshold=3
""".format(
    short=_('Update the images deployed in each container in the SQL Server Big Data Cluster.'),
    long=_('Update the images deployed in each container in the SQL Server Big Data Cluster. '
           'The images updated are based on the docker image passed in. If the updated images '
           'are from a different docker image repository than the currently deployed images, '
           'then the "repository" parameter is also required.'),
    ex1=_('BDC upgrade to a new image tag "cu2" from the same repository.'),
    ex2=_('BDC upgrade to a new images with tag "cu2" from a new repository "foo/bar/baz".'),
    ex3=_('BDC upgrade to a new images with tag "cu2" from the same repository.'
          'The upgrade will wait 30 minutes for the controller to upgrade and 30 minutes for '
          'the controller db to upgrade. It will then wait for the controller and controller db '
          'to run for three minutes without crashing upgrading the rest of the cluster. Each '
          'subsequent phase of the upgrade will have forty minutes to complete.'))


helps['bdc config'] = """
    type: group
    short-summary: {short}
""".format(
    short=_('Configuration commands.'))

helps['bdc config init'] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            azdata bdc config init
        - name: {ex2}
          text: >
            azdata bdc config init --source aks-dev-test --target custom
""".format(
    short=_('Initializes a Big Data Cluster configuration profile that can be used with bdc create.'),
    long=_('Initializes a Big Data Cluster configuration  profile that can be used with bdc create. '
           'The specific source of the configuration profile can be specified in the arguments.'),
    ex1=_('Guided BDC config init experience - you will receive prompts for needed values.'),
    ex2=_('BDC config init with arguments, creates a configuration profile of aks-dev-test in ./custom.'))

helps['bdc config list'] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            azdata bdc config list
        - name: {ex2}
          text: >
            azdata bdc config list --config-profile aks-dev-test
""".format(
    short=_('Lists available configuration profile choices.'),
    long=_('Lists available configuration profile choices for use in `bdc config init`'),
    ex1=_('Shows all available configuration profile names.'),
    ex2=_('Shows json of a specific configuration profile.'))

helps['bdc config show'] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            azdata bdc config show
        - name: {ex2}
          text: >
            azdata bdc config show --config-file custom-config/bdc.json --json-path 'metadata.name'
            --target section.json
        - name: {ex3}
          text: >
            azdata bdc config show --config-file custom-config/bdc.json
            --json-path '$.spec.services.sql.resources' --target section.json
""".format(
    short=_('Shows the BDC\'s current config or the config of a local file you specify, i.e. custom/bdc.json.'),
    long=_('Shows the BDC\'s current config or the config of a local file you specify, i.e. custom/bdc.json. '
           'The command can also take in a json path if you would like to only get a section.  You can also specify'
           ' a target file to output to.  If a target file is not specified, it will just be output to the terminal.'),
    ex1=_('Show the BDC config in your console'),
    ex2=_('In a local config file, get a value at the end of a simple json key path.'),
    ex3=_('In a local config file, gets the resources within a service'))

helps['bdc config add'] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            azdata bdc config add --path custom/control.json
            --json-values 'spec.storage={val1}'
""".format(
    short=_('Add a value for a json path in a config file.'),
    long=_('Adds the value at the json path in the config file.  All examples '
           'below are given in Bash.  If using another command line, please be aware that you may need to escape'
           'quotations appropriately.  Alternatively, you may use the patch file functionality.'),
    ex1=_('Ex 1 - Add control plane storage.'),
    val1=_('{"accessMode":"ReadWriteOnce",'
            '"className":"managed-premium","size":"10Gi"}'))

helps['bdc config remove'] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            azdata bdc config remove --path custom/control.json
            --json-path '.spec.storage'
""".format(
    short=_('Remove a value for a json path in a config file.'),
    long=_('Removes the value at the json path in the config file.  All examples '
           'below are given in Bash.  If using another command line, please be aware that you may need to escape'
           'quotations appropriately.  Alternatively, you may use the patch file functionality.'),
    ex1=_('Ex 1 - Remove control plane storage.'))

helps['bdc config replace'] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            azdata bdc config replace --path custom/control.json
            --json-values '$.spec.endpoints[?(@.name=="Controller")].port=30080'
        - name: {ex2}
          text: >
            azdata bdc config replace --path custom/control.json
            --json-values '{val2}'
        - name: {ex3}
          text: >
            azdata bdc config replace --path custom/bdc.json
            --json-values '$.spec.resources.storage-0.spec={val3}'
""".format(
    short=_('Replace a value for a json path in a config file.'),
    long=_('Replaces the value at the json path in the config file.  All examples'
           'below are given in Bash.  If using another command line, please be aware that you may need to escape'
           'quotations appropriately.  Alternatively, you may use the patch file functionality.'),
    ex1=_('Ex 1 - Replace the port of a single endpoint (Controller Endpoint).'),
    ex2=_('Ex 2 - Replace control plane storage.'),
    val2=_('spec.storage={"accessMode":"ReadWriteOnce",'
            '"className":"managed-premium","size":"10Gi"}'),
    ex3=_('Ex 3 - Replace storage-0 resource spec, including replicas.'),
    val3=_('{"replicas": 2,"storage": {"className": "managed-premium",'
            '"size": "10Gi","accessMode": "ReadWriteOnce"},"type": "Storage"}'))

helps['bdc config patch'] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            azdata bdc config patch --path custom/control.json --patch ./patch.json

                Patch File Example (patch.json):
                    {patch1}
        - name: {ex2}
          text: >
            azdata bdc config patch --path custom/control.json --patch ./patch.json

                Patch File Example (patch.json):
                    {patch2}
        - name: {ex3}
          text: >
            azdata bdc config patch --path custom/bdc.json --patch ./patch.json

                Patch File Example (patch.json):
                    {patch3}
""".format(
    short=_('Patches a config file based on a json patch file.'),
    long=_('Patches the config file according to the given patch file. '
           'Please consult http://jsonpatch.com/ for a better understanding of how the paths should be composed. '
           'The replace operation can use conditionals in its path due to the jsonpath library https://jsonpath.com/. '
           'All patch json files must start with a key of \"patch\" that has an array of patches with their '
           'corresponding op (add, replace, remove), path, and value. '
           'The \"remove\" op does not require a value, just a path. '
           'Please see the examples below.'),
    ex1=_('Ex 1 - Replace the port of a single endpoint (Controller Endpoint) with patch file.'),
    patch1=_('{"patch":[{"op":"replace","path":"$.spec.endpoints[?(@.name==\'Controller\')].port",'
              '"value":30080}]}'),
    ex2=_('Ex 2 - Replace control plane storage with patch file.'),
    patch2=_('{"patch":[{"op":"replace","path":".spec.storage",'
              '"value":{"accessMode":"ReadWriteMany","className":"managed-premium","size":"10Gi"}}]}'),
    ex3=_('Ex 3 - Replace pool storage, including replicas (Storage Pool) with patch file.'),
    patch3=_('{"patch":[{"op":"replace","path":"$.spec.resources.storage-0.spec",'
              '"value":{"replicas": 2,"storage": {"className": "managed-premium","size": "10Gi",'
              '"accessMode": "ReadWriteOnce"},"type": "Storage"}}]}'))

helps['bdc endpoint'] = """
    type: group
    short-summary: {short}
""".format(
    short=_('Endpoint commands.'))

helps['bdc endpoint list'] = """
    type: command
    short-summary: {short}
""".format(
    short=_('Lists the endpoints for the Big Data Cluster.'))

helps['bdc debug'] = """
    type: group
    short-summary: {short}
""".format(
    short=_('Debug commands.'))

helps['bdc debug copy-logs'] = """
    type: command
    short-summary: {short}
    long-summary: {long}
""".format(
    short=_('Copy logs.'),
    long=_('Copy the debug logs from the Big Data Cluster - Kubernetes configuration is required on your system.'))

helps['bdc debug dump'] = """
    type: command
    short-summary: {short}
    long-summary: {long}
""".format(
    short=_('Trigger memory dump.'),
    long=_('Trigger memory dump and copy it out from container - Kubernetes configuration is required on your system.'))

helps['bdc status'] = """
    type: group
    short-summary: {short}
""".format(
    short=_('BDC status commands.'))

helps['bdc status show'] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            azdata bdc status show
        - name: {ex2}
          text: >
            azdata bdc status show --all
        - name: {ex3}
          text: >
            azdata bdc status show --resource control
""".format(
    short=_('Shows the status of the BDC.'),
    long=_('Shows the status of the BDC.'),
    ex1=_('BDC status where the user is logged in.'),
    ex2=_('BDC status with all instances of the resources included.'),
    ex3=_('BDC status of the services which include the control resource.'))

helps['bdc control'] = """
    type: group
    short-summary: {short}
""".format(
    short=_('Control service commands.'))

helps['bdc control status'] = """
    type: group
    short-summary: {short}
""".format(
    short=_('Control service status commands.'))

helps['bdc control status show'] = """
    type: command
    short-summary: {short}
    examples:
        - name: {ex1}
          text: >
            azdata bdc control status show
        - name: {ex2}
          text: >
            azdata bdc control status show --all
        - name: {ex3}
          text: >
            azdata bdc control status show --resource control
""".format(
    short=_('Control service status.'),
    ex1=_('Get status of service.'),
    ex2=_('Get status of control service with all instances.'),
    ex3=_('Get status of the control resource within the control service.'))

helps['bdc sql'] = """
    type: group
    short-summary: {short}
""".format(
    short=_('Sql service commands.'))

helps['bdc sql status'] = """
    type: group
    short-summary: {short}
""".format(
    short=_('Sql service status commands.'))

helps['bdc sql status show'] = """
    type: command
    short-summary: {short}
    examples:
        - name: {ex1}
          text: >
            azdata bdc sql status show
        - name: {ex2}
          text: >
            azdata bdc sql status show --all
        - name: {ex3}
          text: >
            azdata bdc sql status show --resource master
""".format(
    short=_('Sql-server service status.'),
    ex1=_('Get status of sql service.'),
    ex2=_('Get status of sql service with all instances.'),
    ex3=_('Get status of the master resource within the sql service.'))

helps['bdc hdfs'] = """
    type: group
    short-summary: {short}
""".format(
    short=_('Hdfs service commands.'))

helps['bdc hdfs status'] = """
    type: group
    short-summary: {short}
""".format(
    short=_('Hdfs service status commands.'))

helps['bdc hdfs status show'] = """
    type: command
    short-summary: {short}
    examples:
        - name: {ex1}
          text: >
            azdata bdc hdfs status show
        - name: {ex2}
          text: >
            azdata bdc hdfs status show --all
        - name: {ex3}
          text: >
            azdata bdc hdfs status show --resource storage-0
""".format(
    short=_('Hdfs service status.'),
    ex1=_('Get status of hdfs service.'),
    ex2=_('Get status of hdfs service with all instances.'),
    ex3=_('Get status of the storage resource within the hdfs service.'))

helps['bdc spark'] = """
    type: group
    short-summary: {short}
""".format(
    short=_('Spark service commands.'))

helps['bdc spark status'] = """
    type: group
    short-summary: {short}
""".format(
    short=_('Spark service status commands.'))

helps['bdc spark status show'] = """
    type: command
    short-summary: {short}
    examples:
        - name: {ex1}
          text: >
            azdata bdc spark status show
        - name: {ex2}
          text: >
            azdata bdc spark status show --all
        - name: {ex3}
          text: >
            azdata bdc spark status show --resource storage-0
""".format(
    short=_('Spark service status.'),
    ex1=_('Get status of spark service.'),
    ex2=_('Get status of spark service with all instances.'),
    ex3=_('Get status of the storage resource within the spark service.'))

helps['bdc gateway'] = """
    type: group
    short-summary: {short}
""".format(
    short=_('Gateway service commands.'))

helps['bdc gateway status'] = """
    type: group
    short-summary: {short}
""".format(
    short=_('Gateway service status commands.'))

helps['bdc gateway status show'] = """
    type: command
    short-summary: {short}
    examples:
        - name: {ex1}
          text: >
            azdata bdc gateway status show
        - name: {ex2}
          text: >
            azdata bdc gateway status show --all
        - name: {ex3}
          text: >
            azdata bdc gateway status show --resource gateway
""".format(
    short=_('Gateway service status.'),
    ex1=_('Get status of gateway service.'),
    ex2=_('Get status of gateway service with all instances.'),
    ex3=_('Get status of the gateway resource within the gateway service.'))

helps['bdc app'] = """
    type: group
    short-summary: {short}
""".format(
    short=_('App service commands.'))

helps['bdc app status'] = """
    type: group
    short-summary: {short}
""".format(
    short=_('App service status commands.'))

helps['bdc app status show'] = """
    type: command
    short-summary: {short}
    examples:
        - name: {ex1}
          text: >
            azdata bdc app status show
        - name: {ex2}
          text: >
            azdata bdc app status show --all
        - name: {ex3}
          text: >
            azdata bdc app status show --resource appproxy
""".format(
    short=_('App service status.'),
    ex1=_('Get status of app service.'),
    ex2=_('Get status of app service with all instances.'),
    ex3=_('Get status of the appproxy resource within the app service.'))
