# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------


def load_arguments(self, _):
    from azdata.cli.commands.extension import _
    from knack.arguments import ArgumentsContext
    from argcomplete.completers import FilesCompleter

    with ArgumentsContext(self, 'extension add') as c:
        c.argument(
            'source',
            options_list=['--source', '-s'],
            help=_('Path to a extension wheel on disk or URL to an extension'),
            completer=FilesCompleter()
        )

        c.argument(
            'index_url',
            options_list=['--index'],
            help=_('Base URL of the Python Package Index (default https://pypi'
                   '.org/simple). This should point to a repository compliant '
                   'with PEP 503 (the simple repository API) or a local '
                   'directory laid out in the same format.')
        )

        c.argument(
            'pip_proxy',
            options_list=['--pip-proxy'],
            arg_group='Experimental Pip',
            help=_('Proxy for pip to use for extension dependencies in the '
                   'form of [user:passwd@]proxy.server:port')
        )

        c.argument(
            'pip_extra_index_urls',
            options_list=['--pip-extra-index-urls'],
            nargs='+',
            arg_group='Experimental Pip',
            help=_('Space-separated list of extra URLs of package indexes to '
                   'use. This should point to a repository compliant with PEP '
                   '503 (the simple repository API) or a local directory laid '
                   'out in the same format.')
        )

        c.argument(
            'yes',
            options_list=['--yes', '-y'],
            action='store_true',
            help=_('Do not prompt for confirmation.')
        )

    with ArgumentsContext(self, 'extension remove') as c:
        c.argument(
            'name',
            options_list=['--name', '-n'],
            help=_('Name of the extension')
        )

        c.argument(
            'yes',
            options_list=['--yes', '-y'],
            action='store_true',
            help=_('Do not prompt for confirmation.')
        )
