# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------

from knack.help_files import helps
from azdata.cli.commands.hdfs import _


# pylint: disable=line-too-long
helps['bdc hdfs'] = """
    type: group
    short-summary: {short}
""".format(
    short=_('The HDFS module provides commands to access an HDFS file system.'))

# pylint: disable=line-too-long
helps['bdc hdfs shell'] = """
    type: command
    short-summary: {short}
    examples:
        - name: {ex1}
          text: >
            azdata bdc hdfs shell
""".format(
    short=_('The HDFS shell is a simple interactive command shell for HDFS file system.'),
    ex1=_('Launch the shell.'))

# pylint: disable=line-too-long
helps['bdc hdfs ls'] = """
    type: command
    short-summary: {short}
    examples:
        - name: {ex1}
          text: >
            azdata bdc hdfs ls --path "tmp/"
""".format(
    short=_('List the status of the given file or directory. '),
    ex1=_('List Status'))

# pylint: disable=line-too-long
helps['bdc hdfs exists'] = """
    type: command
    short-summary: {short}
    examples:
        - name: {ex1}
          text: >
            azdata bdc hdfs exists --path "tmp/"
""".format(
    short=_('Determine if a file or directory exists.  Returns True if exists and False otherwise.'),
    ex1=_('Check for file or directory existance.'))

# pylint: disable=line-too-long
helps['bdc hdfs mkdir'] = """
    type: command
    short-summary: {short}
    examples:
        - name: {ex1}
          text: >
            azdata bdc hdfs mkdir --path "tmp/"
""".format(
    short=_('Create a directory at the specified path.'),
    ex1=_('Make directory.'))

# pylint: disable=line-too-long
helps['bdc hdfs mv'] = """
    type: command
    short-summary: {short}
    examples:
        - name: {ex1}
          text: >
            azdata bdc hdfs mv --source-path "tmp/" --target-path "dest/"
""".format(
    short=_('Move the specified file or path to the specified location.'),
    ex1=_('Move file or directory.'))

# pylint: disable=line-too-long
helps['bdc hdfs create'] = """
    type: command
    short-summary: {short}
    examples:
        - name: {ex1}
          text: >
            azdata bdc hdfs create --path "tmp/test.txt" --data "This is a test."
""".format(
    short=_('Create the text file at the specified location.  Simple text content can be added via data parameter.'),
    ex1=_('Create file.'))

# pylint: disable=line-too-long
helps['bdc hdfs cat'] = """
    type: command
    short-summary: {short}
    examples:
        - name: {ex1}
          text: >
            azdata bdc hdfs cat --path "tmp/test.txt"
""".format(
    short=_('Read content of a file.  Offset and length in bytes are optional parameters.'),
    ex1=_('Read file.'))

# pylint: disable=line-too-long
helps['bdc hdfs rm'] = """
    type: command
    short-summary: {short}
    examples:
        - name: {ex1}
          text: >
            azdata bdc hdfs rm --path "tmp/"
""".format(
    short=_('Remove a file or directory.'),
    ex1=_('Remove a file or directory.'))

# pylint: disable=line-too-long
helps['bdc hdfs rmr'] = """
    type: command
    short-summary: {short}
    examples:
        - name: {ex1}
          text: >
            azdata bdc hdfs rmr --path "tmp/"
""".format(
    short=_('Recursively remove a file or directory.'),
    ex1=_('Recursive remove directory.'))

# pylint: disable=line-too-long
helps['bdc hdfs chmod'] = """
    type: command
    short-summary: {short}
    examples:
        - name: {ex1}
          text: >
            azdata bdc hdfs chmod --permission 775 --path "tmp/test.txt"
""".format(
    short=_('Change the permission on the specified file or directory.'),
    ex1=_('Change file or directory permission.'))

# pylint: disable=line-too-long
helps['bdc hdfs chown'] = """
    type: command
    short-summary: {short}
    examples:
        - name: {ex1}
          text: >
            azdata bdc hdfs chown --owner hdfs --group superusergroup --path "tmp/test.txt"
""".format(
    short=_('Change the owner or group of the specified file.'),
    ex1=_('Change the owner and group.'))

# pylint: disable=line-too-long
helps['bdc hdfs acl modify'] = """
    type: command
    short-summary: {short}
    examples:
        - name: {ex1}
          text: >
            azdata bdc hdfs acl modify --path "tmp/test.txt" --aclspec "user:bob:rw-"
""".format(
    short=_('Add or modify ACL entries for the given file or directory.'),
    ex1=_('Change the ACL entry for a given user.'))

# pylint: disable=line-too-long
helps['bdc hdfs acl remove'] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            azdata bdc hdfs acl remove --path "tmp/test.txt" --aclspec "user:bob:"
        - name: {ex2}
          text: >
            azdata bdc hdfs acl remove --path "tmp/test.txt" --aclspec default
        - name: {ex3}
          text: >
            azdata bdc hdfs acl remove --path "tmp/test.txt"
""".format(
    short=_("Remove ACL entries for the given file or directory."),
    long=_('Remove ACL entries for the given file or directory.  If aclspec is empty then all non-default ACL entries will be removed. If aclspec is "default" then default ACL entries will be removed.'),
    ex1=_('Remove the ACL entries specified in the aclspec.'),
    ex2 = _('Remove the default acl entries. default:user, default:group, default:other.'),
    ex3 = _('Remove all the non-default ACL entries.'))

# pylint: disable=line-too-long
helps['bdc hdfs acl set'] = """
    type: command
    short-summary: {short}
    examples:
        - name: {ex1}
          text: >
            azdata bdc hdfs acl set --path "tmp/test.txt" --aclspec "user:bob:rw-"
""".format(
    short=_('Replaces all the ACL entries with the specified entries.'),
    ex1=_('Replace the ACL entries for the specified file or directory.'))

# pylint: disable=line-too-long
helps['bdc hdfs acl status'] = """
    type: command
    short-summary: {short}
    examples:
        - name: {ex1}
          text: >
            azdata bdc hdfs acl status --path "tmp/test.txt"
""".format(
    short=_('Returns status of the ACL.'),
    ex1=_('Get ACL state.'))

# pylint: disable=line-too-long
helps['bdc hdfs xattr get'] = """
    type: command
    short-summary: {short}
    examples:
        - name: {ex1}
          text: >
            azdata bdc hdfs xattr get --path "tmp/test.txt" --name "myprop"
""".format(
    short=_('Get the value of the extended attribute for the given path.'),
    ex1=_('Get extended property.'))

# pylint: disable=line-too-long
helps['bdc hdfs xattr set'] = """
    type: command
    short-summary: {short}
    examples:
        - name: {ex1}
          text: >
            azdata bdc hdfs xattr set --path "tmp/test.txt" --name "myprop" --value "1234"
""".format(
    short=_('Set the value of the extended attribute for the given path.  The property must not exist.'),
    ex1=_('Set extended property.'))

# pylint: disable=line-too-long
helps['bdc hdfs xattr modify'] = """
    type: command
    short-summary: {short}
    examples:
        - name: {ex1}
          text: >
            azdata bdc hdfs xattr modify --path "tmp/test.txt" --name "myprop" --value "1234"
""".format(
    short=_('Update the value of the extended attribute for the given path.  The property must exist.'),
    ex1=_('Update extended property.'))

# pylint: disable=line-too-long
helps['bdc hdfs xattr remove'] = """
    type: command
    short-summary: {short}
    examples:
        - name: {ex1}
          text: >
            azdata bdc hdfs xattr remove --path "tmp/test.txt" --name "myprop"
""".format(
    short=_('Remove the extended attribute for the given path.'),
    ex1=_('Remove extended property.'))

# pylint: disable=line-too-long
helps['bdc hdfs xattr status'] = """
    type: command
    short-summary: {short}
    examples:
        - name: {ex1}
          text: >
            azdata bdc hdfs xattr status --path "tmp/test.txt"
""".format(
    short=_('Get the name and value of the extended properties of the given path.'),
    ex1=_('List extended properties and values.'))

# pylint: disable=line-too-long
helps['bdc hdfs cp'] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            azdata bdc hdfs cp --from_path "tmp/test.txt" --to-path "hdfs:/user/me/test.txt"
""".format(
    short=_("Copy a file or directory between the local machine and HDFS."),
    long=_('Copy a file or directory between the local machine and HDFS.  If the input is a directory then the whole directory tree is copied.  If the target file or directory exists the command will fail.  To specify the remote HDFS directory prefix the path with "hdfs:"'),
    ex1=_('Copy file or directory between the local machine and HDFS.'))

helps['bdc hdfs mount'] = """
    type: group
    short-summary: {short}
""".format(
    short=_('Manage mounting of remote stores in HDFS.'))

helps['bdc hdfs mount create'] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            Set the MOUNT_CREDENTIALS environment variable as
            "fs.azure.abfs.account.name=<your-storage-account-name>.dfs.core.windows.net,fs.azure.account.key.<your-storage-account-name>.dfs.core.windows.net=<storage-account-access-key>".

            azdata bdc hdfs mount create --remote-uri abfs://data@adlsv2example.dfs.core.windows.net/
                --mount-path /mounts/adlsv2/data
        - name: {ex2}
          text: >
            azdata bdc hdfs mount create --remote-uri hdfs://namenode1:8080/ --mount-path /mounts/hdfs/
""".format(
    short=_('Create mounts of remote stores in HDFS.'),
    long=_('Create mounts of remote stores in HDFS. The credentials for accessing the remote store, if any, should be '
           'specified using the environment variable MOUNT_CREDENTIALS as a comma-separated list of key=value pairs. '
           'Any commas in the keys or values must be escaped.'),
    ex1=_('To mount container "data" in ADLS Gen 2 account "adlsv2example" on HDFS path /mounts/adlsv2/data using the shared key'),
    ex2=_('To mount a remote HDFS BDC (hdfs://namenode1:8080/) on local HDFS path /mounts/hdfs/'))

helps['bdc hdfs mount delete'] = """
    type: command
    short-summary: {short}
    examples:
        - name: {ex1}
          text: >
            azdata bdc hdfs mount delete --mount-path /mounts/adlsv2/data
""".format(
    short=_('Delete mounts of remote stores in HDFS.'),
    ex1=_('Delete mount created at /mounts/adlsv2/data for a ADLS Gen 2 storage account.'))

helps['bdc hdfs mount status'] = """
    type: command
    short-summary: {short}
    examples:
        - name: {ex1}
          text: >
            azdata bdc hdfs mount status --mount-path /mounts/hdfs
        - name: {ex2}
          text: >
            azdata bdc hdfs mount status
""".format(
    short=_('Status of mount(s).'),
    ex1=_('Get mount status by path'),
    ex2=_('Get status of all mounts.'))

helps['bdc hdfs mount refresh'] = """
    type: command
    short-summary: {short}
    examples:
        - name: {ex1}
          text: >
            azdata bdc hdfs mount refresh --mount-path /mounts/adlsv2/data
""".format(
    short=_('Refresh the contents of a mount in HDFS.'),
    ex1=_('Refresh mount created at /mounts/adlsv2/data.'))
