# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------

from knack.help_files import helps
from azdata.cli.commands.profile import _

# pylint: disable=line-too-long
helps['login'] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: Login using basic authentication.
          text: >
            azdata login --auth basic --username johndoe --endpoint https://<ip or domain name>:30080            
        - name: Login using active directory.
          text: >
            azdata login --auth ad --endpoint https://<ip or domain name>:30080                
        - name: Login using active directory with an explicit principal.
          text: >
            azdata login --auth ad --principal johndoe@COSTOSO.COM --endpoint https://<ip or domain name>:30080
        - name: {ex1}
          text: >
            azdata login
        - name: {ex2}
          text: >
            azdata login --namespace ClusterName --username johndoe@contoso.com 
            --endpoint https://<ip or domain name>:30080 --accept-eula yes
        - name: {ex3}
          text: >
            azdata login -n ClusterName
""".format(
    short=_('Log in to the cluster\'s controller endpoint and set its '
            'namespace as your active context. To use a password on login, you must set the AZDATA_PASSWORD '
            'environment variable.'),
    long=_('When your cluster is deployed, it will list the controller '
           'endpoint during deployment, which you should use to login.  If '
           'you do not know the controller endpoint, you may login by having '
           'your cluster\'s kube config on your system in the default location '
           'of <user home>/.kube/config or use the KUBECONFIG env var, i.e. '
           'export KUBECONFIG=path/to/.kube/config.  When you login, this'
           ' cluster\'s namespace will be set to your active context.'),
    ex1=_('Log in interactively. '
          'Cluster name will always be prompted for if not specified as an '
          'argument. If you have the AZDATA_USERNAME, AZDATA_PASSWORD, '
          'and ACCEPT_EULA env variables set on your system, these will not be '
          'prompted for. If you have the kube config on your system or are '
          'using the KUBECONFIG env var to specify the path to the config, the '
          'interactive experience will first try to use the config and then '
          'prompt you if the config fails.'),
    ex2=_('Log in (non-interactively). '
          'Log in with cluster name, controller user name, controller '
          'endpoint, and EULA acceptance set as arguments. The environment '
          'variable AZDATA_PASSWORD must be set.  If you do not want to '
          'specify the controller endpoint, please have the kube config on '
          'your machine in the default location of <user home>/.kube/config or '
          'use the KUBECONFIG env var, i.e. export '
          'KUBECONFIG=path/to/.kube/config.'),
    ex3=_('Log in with kube config on machine, and env var set for '
          'AZDATA_USERNAME, AZDATA_PASSWORD, and ACCEPT_EULA.')
)

helps['logout'] = """
    type: command
    short-summary: {short}
    examples:
        - name: {ex1}
          text: >
            azdata logout
""".format(
    short=_('Log out of cluster.'),
    ex1=_('Log out this user.')
)

helps['context'] = """
    type: group
    short-summary: {short}
""".format(
    short=_('Context management commands.')
)

helps['context list'] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            azdata context list
        - name: {ex2}
          text: >
            azdata context list --active
""".format(
    short=_('Lists the available contexts in the user profile.'),
    long=_('You may set or delete any of these with `azdata context set` or '
           '`azdata context delete`. To login to a new context, use `azdata '
           'login`.'),
    ex1=_('Lists all available contexts in the user profile.'),
    ex2=_('Lists the active context in the user profile.')
)

helps['context delete'] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            azdata context delete -n contextNamespace
""".format(
    short=_('Deletes the context with the given namespace from the user '
            'profile.'),
    long=_('If the deleted context is active, the user will need to set a new '
           'active context. To see contexts available to set or delete `azdata '
           'context list`'),
    ex1=_('Deletes contextNamespace from the user profile.')
)

helps['context set'] = """
    type: command
    short-summary: {short}
    long-summary: {long}
    examples:
        - name: {ex1}
          text: >
            azdata context set -n contextNamespace
""".format(
    short=_('Sets the context with the given namespace as the active context '
            'in the user profile.'),
    long=_('To see contexts available to set `azdata context list`. If no '
           'contexts are listed, you need to login in order to create a '
           'context in your user profile `azdata login`. What you login to '
           'will become your active context. If you login to multiple '
           'entities, you can then switch between active contexts with this '
           'command. To see your currently active context `azdata context '
           'list --active`'),
    ex1=_('Sets contextNamespace as the active context in the user profile.')
)
