# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------


def load_arguments(self, _):
    from azdata.cli.commands.sql import _
    from knack.arguments import ArgumentsContext

    with ArgumentsContext(self, "sql shell") as arg_context:
        arg_context.argument(
            "username",
            options_list=["--username", "-u"],
            help=_("Username to connect to the database."),
        )
        arg_context.argument(
            "database",
            options_list=["--database", "-d"],
            default="master",
            help=_("Database name to connect to."),
        )
        arg_context.argument(
            "server",
            options_list=["--server", "-s"],
            help=_("SQL Server instance name or address."),
        )
        arg_context.argument(
            "integrated",
            options_list=["--integrated", "-e"],
            action="store_true",
            help=_("Use integrated authentication on windows."),
        )
        arg_context.argument(
            "mssqlclirc",
            options_list=["--mssqlclirc"],
            help=_("Location of mssqlclirc config file."),
        )
        arg_context.argument(
            "row_limit",
            options_list=["--row-limit"],
            type=int,
            help=_(
                "Set threshold for row limit prompt. Use 0 to disable "
                "prompt."
            ),
        )
        arg_context.argument(
            "less_chatty",
            options_list=["--less-chatty"],
            action="store_true",
            help=_("Skip intro on startup and goodbye on exit."),
        )
        arg_context.argument(
            "auto_vertical_output",
            options_list=["--auto-vertical-output"],
            action="store_true",
            help=_(
                "Automatically switch to vertical output mode if the "
                "result is wider than the terminal width."
            ),
        )
        arg_context.argument(
            "encrypt",
            options_list=["--encrypt", "-n"],
            action="store_true",
            help=_(
                "SQL Server uses SSL encryption for all data if the server "
                "has a certificate installed."
            ),
        )
        arg_context.argument(
            "trust_server_certificate",
            options_list=["--trust-server-certificate", "-c"],
            action="store_true",
            help=_(
                "The channel will be encrypted while bypassing walking the "
                "certificate chain to validate trust."
            ),
        )
        arg_context.argument(
            "connect_timeout",
            options_list=["--connect-timeout", "-l"],
            type=int,
            help=_(
                "Time in seconds to wait for a connection to the server "
                "before terminating request."
            ),
        )
        arg_context.argument(
            "application_intent",
            options_list=["--application-intent", "-k"],
            help=_(
                "Declares the application workload type when connecting to "
                "a database in a SQL Server Availability Group."
            ),
        )
        arg_context.argument(
            "multi_subnet_failover",
            options_list=["--multi-subnet-failover", "-m"],
            action="store_true",
            help=_(
                "If application is connecting to AlwaysOn AG on different "
                "subnets, setting this provides faster detection and "
                "connection to currently active server."
            ),
        )
        arg_context.argument(
            "packet_size",
            options_list=["--packet-size"],
            type=int,
            help=_(
                "Size in bytes of the network packets used to communicate "
                "with SQL Server."
            ),
        )
        arg_context.argument(
            "dac_connection",
            options_list=["--dac-connection", "-a"],
            action="store_true",
            help=_(
                "Connect to SQL Server using the dedicated administrator "
                "connection."
            ),
        )
        arg_context.argument(
            "input_file",
            options_list=["--input-file", "-i"],
            help=_(
                "Specifies the file that contains a batch of SQL statements "
                "for processing."
            ),
        )
        arg_context.argument(
            "output_file",
            options_list=["--output-file"],
            help=_("Specifies the file that receives output from a query."),
        )
        arg_context.argument(
            "enable_sqltoolsservice_logging",
            options_list=["--enable-sqltoolsservice-logging"],
            action="store_true",
            help=_("Enables diagnostic logging for the SqlToolsService."),
        )
        arg_context.argument(
            "prompt",
            options_list=["--prompt"],
            help=_("Prompt format (Default: \d>"),
        )

    with ArgumentsContext(self, "sql query") as arg_context:
        arg_context.argument(
            "username",
            options_list=["--username", "-u"],
            help=_("Username to connect to the database."),
        )
        arg_context.argument(
            "database",
            options_list=["--database", "-d"],
            default="master",
            help=_("Database name to connect to."),
        )
        arg_context.argument(
            "server",
            options_list=["--server", "-s"],
            help=_("SQL Server instance name or address."),
        )
        arg_context.argument(
            "integrated",
            options_list=["--integrated", "-e"],
            action="store_true",
            help=_("Use integrated authentication on windows."),
        )
        arg_context.argument(
            "query",
            options_list=["-q"],
            required=True,
            help=_("T-SQL query to execute."),
        )
