# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------

from azdata.cli.commands.sql.util import (
    attempt_bdc_endpoint,
    get_sql_username,
    get_sql_password,
)
from knack.prompting import NoTTYException
from azdata.cli.core.configuration import Configuration
from azdata.cli.core.exceptions import (
    CliError,
    ControllerError,
    http_status_codes,
)


def sql_shell(
    client,
    username=None,
    database=None,
    server=None,
    integrated=False,
    mssqlclirc=None,
    row_limit=None,
    less_chatty=False,
    auto_vertical_output=False,
    encrypt=False,
    trust_server_certificate=False,
    connect_timeout=None,
    application_intent=None,
    multi_subnet_failover=False,
    packet_size=None,
    dac_connection=False,
    input_file=None,
    output_file=None,
    enable_sqltoolsservice_logging=False,
    prompt=None,
):

    """
    ```sh
    azdata sql shell --server localhost
                     --username sa
                     --database master
                     --dac-connection
    ```
    """

    try:
        server = server or attempt_bdc_endpoint(client)
        username = None if integrated else username or get_sql_username()
        password = None if integrated else get_sql_password()

        client.run_shell(
            username=username,
            password=password,
            database=database,
            server=server,
            integrated=integrated,
            mssqlclirc=mssqlclirc,
            row_limit=row_limit,
            less_chatty=less_chatty,
            auto_vertical_output=auto_vertical_output,
            encrypt=encrypt,
            trust_server_certificate=trust_server_certificate,
            connect_timeout=connect_timeout,
            application_intent=application_intent,
            multi_subnet_failover=multi_subnet_failover,
            packet_size=packet_size,
            dac_connection=dac_connection,
            input_file=input_file,
            output_file=output_file,
            enable_sqltoolsservice_logging=enable_sqltoolsservice_logging,
            prompt=prompt,
        )

    # if bdc use it
    except ControllerError as ex:
        if ex.status == http_status_codes.unauthorized:
            ex = (
                "Please run '{0} login' to first authenticate, or set a "
                "valid active context with '{0} context set'.".format(
                    Configuration().CLI_NAME
                )
            )
        raise CliError(ex)
    except (NoTTYException, Exception) as ex:
        raise CliError(ex)


def sql_query(
        client,
        query,
        database="master",
        username=None,
        server=None,
        integrated=False,
):
    """
    ```sh
    azdata sql query --server localhost
                     --username sa
                     --database master
                     -q "SELECT * from SYS.TABLES"

    ```
    """
    from pyodbc import Error as ODBCError

    try:
        server = server or attempt_bdc_endpoint(client)
        username = None if integrated else username or get_sql_username()
        password = None if integrated else get_sql_password()

        if not server:
            server = "localhost"

        return client.run_query(
            server, username, password, database, query, integrated=integrated
        )
    except ControllerError as ex:
        if ex.status == http_status_codes.unauthorized:
            ex = (
                "Please run '{0} login' to first authenticate, or set a "
                "valid active context with '{0} context set'.".format(
                    Configuration().CLI_NAME
                )
            )
        raise CliError(ex)
    except (NoTTYException, ODBCError, Exception) as ex:
        raise CliError(ex)
