# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------

from azdata.cli.core.text import Text
from knack.prompting import NoTTYException
from azdata.cli.core.profile import CliProfile
from azdata.cli.core.prompt import prompt, prompt_pass
from azdata.cli.core.constants import AZDATA_USERNAME, AZDATA_PASSWORD
from azdata.cli.core.enums import SecurityStrategy

import os

__all__ = ["attempt_bdc_endpoint", "get_sql_username", "get_sql_password"]


def attempt_bdc_endpoint(client):
    """
    If the active context is `bdc` then try and retrieve the SQL Server address
    based on `sql-server-master`.
    @:return The SQL SQL Server address for `bdc` otherwise `None`
    """
    from azdata.cli.core.enums import ContextType

    endpoint = None
    ctx = CliProfile().active_context

    # If BDC use this default
    if ctx and ctx.context_type == ContextType.bdc.name:
        ctrl = client.apis.controller
        endpoint = ctrl.get_endpoints("sql-server-master")["endpoint"]

    return endpoint


def get_sql_username():
    if CliProfile().active_context.security_strategy == SecurityStrategy.ad:
        return None

    username = os.environ.get(AZDATA_USERNAME)

    if not username:
        try:
            msg = (
                "\nThe SQL Server username is needed. It can be set for the "
                'session by setting the environment\nvariable "{}".'.format(
                    AZDATA_USERNAME
                )
            )
            Text.warning(msg)

            username = prompt("Enter SQL Server username: ")
        except NoTTYException:
            raise NoTTYException(
                'Missing [--username, -u] or "AZDATA_USERNAME" environment '
                "variable\nin non-interactive environment.".format(
                    AZDATA_USERNAME
                )
            )

    return username


def get_sql_password():
    if CliProfile().active_context.security_strategy == SecurityStrategy.ad:
        return None

    env = os.environ.get
    password = env("MSSQL_CLI_PASSWORD") or env(AZDATA_PASSWORD)

    if not password:
        try:
            msg = (
                "\nThe SQL login password is needed."
            )
            Text.warning(msg)

            password = prompt_pass("Enter SQL Server Password: ")
        except NoTTYException:
            raise NoTTYException(
                'Missing "{}" or "MSSQL_CLI_PASSWORD" environment '
                "variable in non-interactive environment.".format(
                    AZDATA_PASSWORD
                )
            )

    return password
