# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------
import re
from azdata.cli.commands.sqlmi.constants import (
    SQLMI_PASSWORD_CHARS,
    SQLMI_PASSWORD_MIN_LENGTH,
    SQLMI_PASSWORD_REQUIRED_GROUPS)


def is_valid_sql_password(pw, user):
    """
    Checks if the provided pw is a valid sql server password i.e. is at least
    eight characters long and contains a char from at least three of these groups
    -Uppercase letters
    -Lowercase letters
    -Base 10 digits
    -Non-alphanumeric characters
    :param pw: the password
    :param user: username for the sql instance
    :return: True if pw meets requirements, False otherwise
    """
    if not pw:
        return False

    if user in pw:
        return False

    if len(pw) < SQLMI_PASSWORD_MIN_LENGTH:
        return False

    lower = 0
    upper = 0
    special = 0
    digit = 0

    for c in pw:
        if c.isdigit():
            digit = 1
        elif c.isalpha():
            if c.isupper():
                upper = 1
            else:
                lower = 1

    special_chars = re.compile(SQLMI_PASSWORD_CHARS)
    if special_chars.search(pw) is not None:
        special = 1

    return (lower + upper + special + digit) >= SQLMI_PASSWORD_REQUIRED_GROUPS
